@@ -1,3 +1,5 @@
 from chessdotcom.errors import ChessDotComError
 from chessdotcom.caller import *
-from chessdotcom.response_parser import ChessDotComResponse
\ No newline at end of file
+from chessdotcom.response import ChessDotComResponse
+
+
