@@ -57,7 +57,7 @@ class _internal:
 def get_player_profile(username: str):
     """
     :param username: username of the player.
-    :returns: A ChessDotComResponse response object. The json property of the object
+    :returns: ``ChessDotComResponse`` object. The json property of the object
                 contains information about the chess.com user.
     """
 
@@ -68,7 +68,7 @@ def get_player_profile(username: str):
 def get_titled_players(title_abbrev: str):
     """
     :param title_abbrev: abbreviation of chess title.
-    :returns: A ChessDotComResponse response object. The json property of the object
+    :returns: ``ChessDotComResponse`` object. The json property of the object
                 contains a list of usernames who have the specified title.
     """
 
@@ -79,7 +79,7 @@ def get_titled_players(title_abbrev: str):
 def get_player_stats(username: str):
     """
     :param username: username of the player.
-    :returns: A ChessDotComResponse response object. The json property of the object
+    :returns: ``ChessDotComResponse`` object. The json property of the object
                 contains ratings, win/loss,
                 and other stats about a player's game play, tactics,
                 lessons and Puzzle Rush score.
@@ -91,17 +91,17 @@ def get_player_stats(username: str):
 def is_player_online(username: str):
     """
     :param username: username of the player.
-    :returns: True if the user is online, False otherwise.
-
+    :returns: ``ChessDotComResponse`` object. The json property of the object
+                contains information about whether or not the player is online. 
     """
     r = _internal.do_get_request(path = f"/player/{username}/is-online")
-    return ChessDotComResponse(response_data = r.data).json["online"]
+    return ChessDotComResponse(response_data = r.data)
 
 
 def get_player_current_games(username: str):
     """
     :param username: username of the player.
-    :returns: A ChessDotComResponse response object. The json property of the object
+    :returns: ``ChessDotComResponse`` object. The json property of the object
                 contains a list of Daily Chess games that a player is currently playing.
 
     """
@@ -112,7 +112,7 @@ def get_player_current_games(username: str):
 def get_player_current_games_to_move(username: str):
     """
     :param username: username of the player.
-    :returns: A ChessDotComResponse response object. The json property of the object
+    :returns: ``ChessDotComResponse`` object. The json property of the object
                 contains a list of Daily Chess games where it is the player's turn to act.
 
     """
@@ -123,7 +123,7 @@ def get_player_current_games_to_move(username: str):
 def get_player_game_archives(username: str):
     """
     :param username: username of the player.
-    :returns: A ChessDotComResponse response object. The json property of the object
+    :returns: ``ChessDotComResponse`` object. The json property of the object
                 contains a list of monthly archives available for this player.
 
     """
@@ -140,7 +140,7 @@ def get_player_games_by_month(username: str, year: Optional[Union[str, int, None
     :param month: the month (mm).
     :param date: datetime.datetime of the month. Can be passed in instead of month
                     and year parameters.
-    :returns: A ChessDotComResponse response object. The json property of the object
+    :returns: ``ChessDotComResponse`` object. The json property of the object
                 contains a list of live and daily Chess games that a player has finished.
 
     """
@@ -158,18 +158,20 @@ def get_player_games_by_month_pgn(username: str, year: Optional[Union[str, int,
     :param month: the month (mm).
     :param date: datetime.datetime of the month. Can be passed in instead of month
                     and year parameters.
-    :returns: standard multi-game format PGN
-                containing all games for a month.
+    :returns: ``ChessDotComResponse`` object. The json property of the object contains 
+                standard multi-game format PGN containing all games for a month.
     """
     yyyy, mm = _internal.resolve_date(year, month, datetime_obj)
     r = _internal.do_get_request(path = f"/player/{username}/games/{yyyy}/{mm}/pgn")
-    return r.data
+    return ChessDotComResponse(response_data = json.dumps({
+            'pgn': r.data.decode('utf-8')
+        }).encode('utf-8'))
 
 
 def get_player_clubs(username: str):
     """
     :param username: username of the player.
-    :returns: A ChessDotComResponse response object. The json property of the object
+    :returns: ``ChessDotComResponse`` object. The json property of the object
                 contains a list of clubs the player is a member of.
     """
     r = _internal.do_get_request(path = f"/player/{username}/clubs")
@@ -179,7 +181,7 @@ def get_player_clubs(username: str):
 def get_player_team_matches(username: str):
     """
     :param username: username of the player.
-    :returns: A ChessDotComResponse response object. The json property of the object
+    :returns: ``ChessDotComResponse`` object. The json property of the object
                 contains a list of team matches the player has attended,
                 is participating or is currently registered.
     """
@@ -190,7 +192,7 @@ def get_player_team_matches(username: str):
 def get_player_tournaments(username: str):
     """
     :param username: username of the player.
-    :returns: A ChessDotComResponse response object. The json property of the object
+    :returns: ``ChessDotComResponse`` object. The json property of the object
                 contains a list of tournaments the player is registered,
                 is attending or has attended in the past.
     """
@@ -201,7 +203,7 @@ def get_player_tournaments(username: str):
 def get_club_details(url_id: str):
     """
     :param url_id: URL for the club's web page on www.chess.com.
-    :returns: A ChessDotComResponse response object. The json property of the object
+    :returns: ``ChessDotComResponse`` object. The json property of the object
                 contains additional details about a club.
     """
     r = _internal.do_get_request(path = f"/club/{url_id}")
@@ -211,7 +213,7 @@ def get_club_details(url_id: str):
 def get_club_members(url_id: str):
     """
     :param url_id: URL for the club's web page on www.chess.com.
-    :returns: A ChessDotComResponse response object. The json property of the object
+    :returns: ``ChessDotComResponse`` object. The json property of the object
                 contains a list of club members.
     """
     r = _internal.do_get_request(path = f"/club/{url_id}/members")
@@ -221,7 +223,7 @@ def get_club_members(url_id: str):
 def get_club_matches(url_id: str):
     """
     :param url_id: URL for the club's web page on www.chess.com.
-    :returns: A ChessDotComResponse response object. The json property of the object
+    :returns: ``ChessDotComResponse`` object. The json property of the object
                 contains a list of daily and club matches.
     """
     r = _internal.do_get_request(path = f"/club/{url_id}/matches")
@@ -231,7 +233,7 @@ def get_club_matches(url_id: str):
 def get_tournament_details(url_id: str):
     """
     :param url_id: URL for the club's web page on www.chess.com.
-    :returns: A ChessDotComResponse response object. The json property of the object
+    :returns: ``ChessDotComResponse`` object. The json property of the object
                 contains details about a daily, live and arena tournament.
     """
     r = _internal.do_get_request(path = f"/tournament/{url_id}")
@@ -242,7 +244,7 @@ def get_tournament_round(url_id: str, round_num: int):
     """
     :param url_id: URL for the club's web page on www.chess.com.
     :param round_num: the round of the tournament.
-    :returns: A ChessDotComResponse response object. The json property of the object
+    :returns: ``ChessDotComResponse`` object. The json property of the object
                 contains details about a tournament's round.
     """
     r = _internal.do_get_request(path = f"/tournament/{url_id}/{round_num}")
@@ -254,7 +256,7 @@ def get_tournament_round_group_details(url_id: str, round_num: int, group_num: i
     :param url_id: URL for the club's web page on www.chess.com.
     :param round_num: the round of the tournament.
     :param group_num: the group in the tournament.
-    :returns: A ChessDotComResponse response object. The json property of the object
+    :returns: ``ChessDotComResponse`` object. The json property of the object
                 contains details about a tournament's round group.
     """
     r = _internal.do_get_request(path = f"/tournament/{url_id}/{round_num}/{group_num}")
@@ -264,7 +266,7 @@ def get_tournament_round_group_details(url_id: str, round_num: int, group_num: i
 def get_team_match(match_id: int):
     """
     :param match_id: the id of the match.
-    :returns: A ChessDotComResponse response object. The json property of the object
+    :returns: ``ChessDotComResponse`` object. The json property of the object
                 contains details about a team match and players playing that match.
     """
     r = _internal.do_get_request(path = f"/match/{match_id}")
@@ -275,7 +277,7 @@ def get_team_match_board(match_id: int, board_num: int):
     """
     :param match_id: the id of the match.
     :param board_num: the number of the board.
-    :returns: A ChessDotComResponse response object. The json property of the object
+    :returns: ``ChessDotComResponse`` object. The json property of the object
                 contains details about a team match board.
     """
     r = _internal.do_get_request(path = f"/match/{match_id}/{board_num}")
@@ -285,7 +287,7 @@ def get_team_match_board(match_id: int, board_num: int):
 def get_team_match_live(match_id: int):
     """
     :param match_id: the id of the match.
-    :returns: A ChessDotComResponse response object. The json property of the object
+    :returns: ``ChessDotComResponse`` object. The json property of the object
                 contains details about a team match and players playing that match.
     """
     r = _internal.do_get_request(path = f"/match/live/{match_id}")
@@ -296,7 +298,7 @@ def get_team_match_live_board(match_id: int, board_num: int):
     """
     :param match_id: the id of the match.
     :param board_num: the number of the board.
-    :returns: A ChessDotComResponse response object. The json property of the object
+    :returns: ``ChessDotComResponse`` object. The json property of the object
                 contains details about a team match board.
     """
     r = _internal.do_get_request(path = f"/match/live/{match_id}/{board_num}")
@@ -306,7 +308,7 @@ def get_team_match_live_board(match_id: int, board_num: int):
 def get_country_details(iso: str):
     """
     :param iso: country's 2-character ISO 3166 code.
-    :returns: A ChessDotComResponse response object. The json property of the object
+    :returns: ``ChessDotComResponse`` object. The json property of the object
                 contains additional details about a country.
     """
     r = _internal.do_get_request(path = f"/country/{iso}")
@@ -316,7 +318,7 @@ def get_country_details(iso: str):
 def get_country_players(iso: str):
     """
     :param iso: country's 2-character ISO 3166 code.
-    :returns: A ChessDotComResponse response object. The json property of the object
+    :returns: ``ChessDotComResponse`` object. The json property of the object
                 contains a list of usernames for players
                 who identify themselves as being in this country.
     """
@@ -327,7 +329,7 @@ def get_country_players(iso: str):
 def get_country_clubs(iso: str):
     """
     :param iso: country's 2-character ISO 3166 code.
-    :returns: A ChessDotComResponse response object. The json property of the object
+    :returns: ``ChessDotComResponse`` object. The json property of the object
                 contains a list of URLs for clubs identified
                 as being in or associated with this country.
     """
@@ -337,8 +339,8 @@ def get_country_clubs(iso: str):
 
 def get_current_daily_puzzle():
     """
-    :returns: information
-                    about the daily puzzle found in www.chess.com.
+    :returns: ``ChessDotComResponse`` object. The json property of the object contains
+                information about the daily puzzle found in www.chess.com.
     """
     r = _internal.do_get_request("/puzzle")
     return ChessDotComResponse(response_data = r.data)
@@ -346,7 +348,8 @@ def get_current_daily_puzzle():
 
 def get_random_daily_puzzle():
     """
-    :returns: information about a randomly picked daily puzzle.
+    :returns: ``ChessDotComResponse`` object. The json property of the object contains 
+                information about a randomly picked daily puzzle.
     """
     r = _internal.do_get_request(path = "/puzzle/random")
     return ChessDotComResponse(response_data = r.data)
@@ -354,7 +357,8 @@ def get_random_daily_puzzle():
 
 def get_streamers():
     """
-    :returns: information about Chess.com streamers.
+    :returns: ``ChessDotComResponse`` object. The json property of the object contains 
+                information about Chess.com streamers.
     """
     r = _internal.do_get_request(path = "/streamers")
     return ChessDotComResponse(response_data = r.data)
@@ -362,8 +366,8 @@ def get_streamers():
 
 def get_leaderboards():
     """
-    :returns: information about top 50 player
-                for daily and live games, tactics and lessons.
+    :returns: ``ChessDotComResponse`` object. The json property of the object contains 
+                information about top 50 player for daily and live games, tactics and lessons.
     """
     r = _internal.do_get_request(path = "/leaderboards")
     return ChessDotComResponse(response_data = r.data)
